"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSummaryByDistance = void 0;
const distance_1 = require("./distance");
function getSummaryByDistance({ mainFingerprint, candidates, variables, }) {
    const summaryStart = process.hrtime.bigint();
    const distanceTimes = [];
    let numCandidates = 0;
    let numInstances = 0;
    let groups = [0, 0, 0, 0, 0]; // index 4 holds distances of 4 and greater.
    // iterate each fingerprint that came back, and collect summary results.
    candidates.forEach((candidate) => {
        var _a, _b, _c, _d;
        const result = distance_1.processDistance({ mainFingerprint, candidate, variables });
        if (result.candidate) {
            numCandidates++;
            numInstances += result.candidate.count;
            groups[Math.min(result.candidate.distance, 4)]++;
            if ((_b = (_a = result.candidate.meta) === null || _a === void 0 ? void 0 : _a.timing) === null || _b === void 0 ? void 0 : _b.distance) {
                distanceTimes.push((_d = (_c = result.candidate.meta) === null || _c === void 0 ? void 0 : _c.timing) === null || _d === void 0 ? void 0 : _d.distance);
            }
        }
    });
    return {
        // Own fingerprint info:
        fingerprint: mainFingerprint.fingerprint,
        dates: mainFingerprint.dates,
        count: mainFingerprint.count,
        state: mainFingerprint.state,
        // Similarity info:
        candidates: numCandidates,
        candidateInstances: numInstances,
        groupedByDistance: groups,
        // Timing
        meta: {
            timing: {
                summary: (process.hrtime.bigint() - summaryStart).toString(),
                distances: distanceTimes,
            },
        },
    };
}
exports.getSummaryByDistance = getSummaryByDistance;
//# sourceMappingURL=summary.js.map